@@ -25,9 +25,17 @@ communicate_summary <- function(changed, ruler_width) {
   if (!getOption("styler.quiet", FALSE)) {
     cli::cat_rule(width = max(40, ruler_width))
     cat("Status\tCount\tLegend \n")
-    cli::cat_bullet("\t", sum(!changed, na.rm = TRUE), "\tFile unchanged.", bullet = "tick")
-    cli::cat_bullet("\t", sum(changed, na.rm = TRUE), "\tFile changed.", bullet = "info")
-    cli::cat_bullet(bullet = "cross", "\t", sum(is.na(changed)), "\tStyling threw an error.")
+    cli::cat_bullet(
+      "\t", sum(!changed, na.rm = TRUE), "\tFile unchanged.",
+      bullet = "tick"
+    )
+    cli::cat_bullet(
+      "\t", sum(changed, na.rm = TRUE), "\tFile changed.",
+      bullet = "info"
+    )
+    cli::cat_bullet(
+      bullet = "cross", "\t", sum(is.na(changed)), "\tStyling threw an error."
+    )
     cli::cat_rule(width = max(40, ruler_width))
   }
 }
