@@ -10,7 +10,7 @@
 #'   {
 #'     string_to_format <- "call( 3)"
 #'     pd <- styler:::compute_parse_data_nested(string_to_format)
-#'     styler:::pre_visit(pd, c(default_style_guide_attributes))
+#'     styler:::pre_visit_one(pd, default_style_guide_attributes)
 #'   }
 #' )
 #' @export
@@ -37,7 +37,7 @@ NULL
 #' @describeIn initialize_attributes Initializes `newlines` and `lag_newlines`.
 #' @keywords internal
 initialize_newlines <- function(pd_flat) {
-  pd_flat$line3 <- lead(pd_flat$line1, default = tail(pd_flat$line2, 1))
+  pd_flat$line3 <- lead(pd_flat$line1, default = tail(pd_flat$line2, 1L))
   pd_flat$newlines <- pd_flat$line3 - pd_flat$line2
   pd_flat$lag_newlines <- lag(pd_flat$newlines, default = 0L)
   pd_flat$line3 <- NULL
@@ -47,7 +47,7 @@ initialize_newlines <- function(pd_flat) {
 #' @describeIn initialize_attributes Initializes `spaces`.
 #' @keywords internal
 initialize_spaces <- function(pd_flat) {
-  pd_flat$col3 <- lead(pd_flat$col1, default = tail(pd_flat$col2, 1) + 1L)
+  pd_flat$col3 <- lead(pd_flat$col1, default = tail(pd_flat$col2, 1L) + 1L)
   pd_flat$col2_nl <- ifelse(pd_flat$newlines > 0L,
     rep(0L, nrow(pd_flat)), pd_flat$col2
   )
@@ -83,7 +83,7 @@ initialize_indention_ref_pos_id <- function(pd_flat) {
 #' @keywords internal
 initialize_indent <- function(pd_flat) {
   if (!("indent" %in% names(pd_flat))) {
-    pd_flat$indent <- 0
+    pd_flat$indent <- 0L
   }
   pd_flat
 }
