@@ -8,22 +8,24 @@
 #' @keywords internal
 create_tree <- function(text, structure_only = FALSE) {
   compute_parse_data_nested(text, transformers = NULL) %>%
-    pre_visit(c(default_style_guide_attributes)) %>%
+    pre_visit_one(default_style_guide_attributes) %>%
     create_tree_from_pd_with_default_style_attributes(structure_only)
 }
 
-create_tree_from_pd_with_default_style_attributes <- function(pd, structure_only = FALSE) {
+create_tree_from_pd_with_default_style_attributes <- function(pd,
+                                                              structure_only = FALSE) {
   pd %>%
     create_node_from_nested_root(structure_only) %>%
+    # don't use `styler_df()` here; `vctrs::data_frame()` only accepts a vector, not a <Node/R6> object
     as.data.frame()
 }
 
 
-#' Convert a nested tibble into a node tree
+#' Convert a nested data frame into a node tree
 #'
-#' This function is convenient to display all nesting levels of a nested tibble
+#' This function is convenient to display all nesting levels of a nested data frame
 #' at once.
-#' @param pd_nested A nested tibble.
+#' @param pd_nested A nested data frame.
 #' @param structure_only Whether or not create a tree that represents the
 #'   structure of the expression without any information on the tokens. Useful
 #'   to check whether two structures are identical.
@@ -35,18 +37,24 @@ create_tree_from_pd_with_default_style_attributes <- function(pd, structure_only
 #'     {
 #'       code <- "a <- function(x) { if(x > 1) { 1+1 } else {x} }"
 #'       nested_pd <- styler:::compute_parse_data_nested(code)
-#'       initialized <- styler:::pre_visit(nested_pd, c(default_style_guide_attributes))
-#'       styler:::create_node_from_nested_root(initialized, structure_only = FALSE)
+#'       initialized <- styler:::pre_visit_one(
+#'         nested_pd, default_style_guide_attributes
+#'       )
+#'       styler:::create_node_from_nested_root(initialized,
+#'         structure_only = FALSE
+#'       )
 #'     }
 #'   )
 #' }
 #' @keywords internal
 create_node_from_nested_root <- function(pd_nested, structure_only) {
   assert_data.tree_installation()
-  n <- data.tree::Node$new(ifelse(
-    structure_only, "Hierarchical structure",
+  name <- if (structure_only) {
+    "Hierarchical structure"
+  } else {
     "ROOT (token: short_text [lag_newlines/spaces] {pos_id})"
-  ))
+  }
+  n <- data.tree::Node$new(name)
   create_node_from_nested(pd_nested, n, structure_only)
   n
 }
