@@ -22,11 +22,11 @@
 #'   code(to = execute)
 #' })
 #' call2(
-#'   x = 2,
-#'   {
+#'   x = 2, {
 #'     code(to = execute)
 #'   },
-#'   c = { # this is the named case
+#'   c = {
+#'     # this is the named case
 #'     g(x = 7)
 #'   }
 #' )
@@ -55,53 +55,66 @@
 #' }
 set_line_break_before_curly_opening <- function(pd) {
   line_break_to_set_idx <- which(
-    (pd$token_after == "'{'") & (pd$token != "COMMENT")
+    (pd$token_after == "'{'") & !(pd$token %in% c("COMMENT", "EQ_FORMALS"))
   )
 
   line_break_to_set_idx <- setdiff(line_break_to_set_idx, nrow(pd))
-  if (length(line_break_to_set_idx) > 0) {
+  if (length(line_break_to_set_idx) > 0L) {
     is_not_curly_curly <- map_chr(
       line_break_to_set_idx + 1L,
       ~ next_terminal(pd[.x, ], vars = "token_after")$token_after
     ) != "'{'"
     last_expr_idx <- max(which(pd$token == "expr"))
-    is_last_expr <- ifelse(pd$token[1] == "IF",
-      # rule not applicable for IF
-      TRUE, (line_break_to_set_idx + 1L) == last_expr_idx
-    )
-
-    no_line_break_before_curly_idx <- pd$token[line_break_to_set_idx] %in% "EQ_SUB"
+    is_last_expr <- if (any(c("IF", "WHILE") == pd$token[1L])) {
+      # rule not applicable for if and while
+      TRUE
+    } else {
+      (line_break_to_set_idx + 1L) == last_expr_idx
+    }
+    no_line_break_before_curly_idx <- any(pd$token[line_break_to_set_idx] == "EQ_SUB")
     linebreak_before_curly <- ifelse(is_function_call(pd),
-      # if in function call and has pipe, it is not recognized as function call and
-      # goes to else case
-      any(pd$lag_newlines[seq2(1, line_break_to_set_idx[1])] > 0),
+      # if in function call and has pipe, it is not recognized as function call
+      # and goes to else case
+      any(pd$lag_newlines[seq2(1, line_break_to_set_idx[1L])] > 0L),
       # if not a function call, only break line if it is a pipe followed by {}
       pd$token[line_break_to_set_idx] %in% c("SPECIAL-PIPE", "PIPE")
     )
     # no line break before last brace expression and named brace expression to
     should_be_on_same_line <- is_not_curly_curly &
-      ((is_last_expr & !linebreak_before_curly) | no_line_break_before_curly_idx)
+      (
+        (is_last_expr & !linebreak_before_curly) |
+          no_line_break_before_curly_idx
+      )
     is_not_curly_curly_idx <- line_break_to_set_idx[should_be_on_same_line]
-    pd$lag_newlines[1 + is_not_curly_curly_idx] <- 0L
+    pd$lag_newlines[1L + is_not_curly_curly_idx] <- 0L
 
 
     # other cases: line breaks
     should_not_be_on_same_line <- is_not_curly_curly &
-      ((!is_last_expr | linebreak_before_curly) & !no_line_break_before_curly_idx)
-    should_not_be_on_same_line_idx <- line_break_to_set_idx[should_not_be_on_same_line]
-
-    pd$lag_newlines[1 + should_not_be_on_same_line_idx] <- 1L
+      (
+        (!is_last_expr | linebreak_before_curly) &
+          !no_line_break_before_curly_idx
+      )
+    should_not_be_on_same_line_idx <- line_break_to_set_idx[
+      should_not_be_on_same_line
+    ]
+    if (is_function_dec(pd)) {
+      should_not_be_on_same_line_idx <- setdiff(
+        1L + should_not_be_on_same_line_idx, nrow(pd)
+      )
+    } else {
+      should_not_be_on_same_line_idx <- 1L + should_not_be_on_same_line_idx
+    }
+    pd$lag_newlines[should_not_be_on_same_line_idx] <- 1L
 
     # non-curly expressions after curly expressions must have line breaks
-    if (length(should_not_be_on_same_line_idx) > 0) {
+    if (length(should_not_be_on_same_line_idx) > 0L) {
       comma_exprs_idx <- which(pd$token == "','")
       comma_exprs_idx <- setdiff(comma_exprs_idx, 1 + is_not_curly_curly_idx)
       non_comment_after_comma <- map_int(comma_exprs_idx,
         next_non_comment,
         pd = pd
       )
-      non_comment_after_expr <-
-        non_comment_after_comma[non_comment_after_comma > should_not_be_on_same_line_idx[1]]
       pd$lag_newlines[non_comment_after_comma] <- 1L
     }
   }
@@ -113,18 +126,18 @@ set_line_break_around_comma_and_or <- function(pd, strict) {
   ops <- c("','", "AND", "OR", "AND2", "OR2")
   comma_with_line_break_that_can_be_removed_before <-
     (pd$token %in% ops) &
-      (pd$lag_newlines > 0) &
+      (pd$lag_newlines > 0L) &
       (pd$token_before != "COMMENT") &
-      (lag(pd$token) != "'['")
+      !(lag(pd$token) %in% subset_token_opening)
 
   pd$lag_newlines[comma_with_line_break_that_can_be_removed_before] <- 0L
   pd$lag_newlines[lag(comma_with_line_break_that_can_be_removed_before)] <- 1L
 
   comma_with_line_break_that_can_be_moved_two_tokens_left <- which(
     (pd$token == "EQ_SUB") &
-      (pd$lag_newlines > 0) &
+      (pd$lag_newlines > 0L) &
       (pd$token_before != "COMMENT") &
-      (lag(pd$token) != "'['")
+      !(lag(pd$token) %in% subset_token_opening)
   )
 
   pd$lag_newlines[comma_with_line_break_that_can_be_moved_two_tokens_left] <- 0L
@@ -138,21 +151,24 @@ set_line_break_around_comma_and_or <- function(pd, strict) {
 }
 
 style_line_break_around_curly <- function(strict, pd) {
-  if (is_curly_expr(pd) && nrow(pd) > 2) {
+  if (is_curly_expr(pd) && nrow(pd) > 2L) {
     closing_before <- pd$token == "'}'"
-    opening_before <- (pd$token == "'{'") & (pd$token_after != "COMMENT")
+    opening_before <- (pd$token == "'{'")
     to_break <- lag(opening_before, default = FALSE) | closing_before
     len_to_break <- sum(to_break)
-    pd$lag_newlines[to_break] <- ifelse(rep(strict, len_to_break),
-      1L,
-      pmax(1L, pd$lag_newlines[to_break])
+    pd$lag_newlines[to_break] <- ifelse(
+      pd$token[to_break] == "COMMENT",
+      pmin(1L, pd$lag_newlines[to_break]),
+      if (strict) 1L else pmax(1L, pd$lag_newlines[to_break])
     )
   } else {
     is_else <- pd$token == "ELSE"
     if (any(pd$token_before[is_else] == "'}'")) {
       pd$lag_newlines[is_else] <- 0L
-      pd$spaces[c(is_else, FALSE)[-1]] <- 1L
+      pd$spaces[c(is_else, FALSE)[-1L]] <- 1L
     }
+    is_if_after_else <- pd$token == "ELSE" & pd$token_after == "IF"
+    pd$lag_newlines[lag(is_if_after_else)] <- 0L
   }
   pd
 }
@@ -179,8 +195,8 @@ style_line_break_around_curly <- function(strict, pd) {
 #' curly-curly affects styling of line break and spaces, namely:
 #'
 #' * No line break after first or second `\{`, before third and fourth `\{`.
-#' * No space after first and third `\{`, one space after second and before third
-#'   `\}`.
+#' * No space after first and third `\{`, one space after second and before
+#'   third `\}`.
 #' * No line breaks within curly-curly, e.g. `\{\{ x \}\}` can only contain line
 #'   breaks after the last brace or before the first brace. But these are not
 #'   dependent on curly-curly specifically.
@@ -213,7 +229,11 @@ remove_line_break_before_round_closing_after_curly <- function(pd) {
 
 remove_line_breaks_in_fun_dec <- function(pd) {
   if (is_function_dec(pd)) {
-    round_after <- (pd$token == "')'" | pd$token_before == "'('") & pd$token_before != "COMMENT"
+    round_after <- (
+      pd$token == "')'" | pd$token_before == "'('"
+    ) &
+      pd$token_before != "COMMENT"
+
     pd$lag_newlines[pd$lag_newlines > 1L] <- 1L
     pd$lag_newlines[round_after] <- 0L
   }
@@ -223,9 +243,9 @@ remove_line_breaks_in_fun_dec <- function(pd) {
 #' @importFrom rlang seq2
 add_line_break_after_pipe <- function(pd) {
   is_pipe <- pd$token %in% c("SPECIAL-PIPE", "PIPE")
-  pd$lag_newlines[lag(is_pipe) & pd$lag_newlines > 1] <- 1L
+  pd$lag_newlines[lag(is_pipe) & pd$lag_newlines > 1L] <- 1L
 
-  if (sum(is_pipe & pd$token_after != "COMMENT") > 1 &&
+  if (sum(is_pipe & pd$token_after != "COMMENT") > 1L &&
     !(next_terminal(pd, vars = "token_before")$token_before %in% c("'('", "EQ_SUB", "','"))) {
     pd$lag_newlines[lag(is_pipe) & pd$token != "COMMENT"] <- 1L
   }
@@ -279,25 +299,29 @@ set_line_break_after_opening_if_call_is_multi_line <- function(pd,
   if (!is_function_call(pd) && !is_subset_expr(pd)) {
     return(pd)
   }
-  has_force_text_before <- last(pd$child[[1]]$text) %in% force_text_before
+  has_force_text_before <- last(pd$child[[1L]]$text) %in% force_text_before
   if (has_force_text_before) {
     break_pos <- c(
       which(lag(pd$token %in% c("','", "COMMENT"))),
       nrow(pd) # always break before last because this is multi-line
     )
   } else {
-    if (!any(pd$lag_newlines[seq2(3L, nrow(pd))] > 0)) {
+    if (!any(pd$lag_newlines[seq2(3L, nrow(pd))] > 0L)) {
       return(pd)
     }
     break_pos <- find_line_break_position_in_multiline_call(pd)
+    idx_nested <- next_non_comment(pd, 2)
+    if (pd_is_multi_line(pd$child[[idx_nested]]) && sum(pd$lag_newlines) > 0L) {
+      break_pos <- c(break_pos, idx_nested)
+    }
   }
   exception_pos <- c(
     which(pd$token %in% except_token_after),
-    ifelse(last(pd$child[[1]]$text) %in% except_text_before, break_pos, NA)
+    ifelse(last(pd$child[[1L]]$text) %in% except_text_before, break_pos, NA)
   )
   pd$lag_newlines[setdiff(break_pos, exception_pos)] <- 1L
   if (has_force_text_before) {
-    first_arg <- which(pd$token == "expr")[2]
+    first_arg <- which(pd$token == "expr")[2L]
     if (lag(pd$token)[first_arg] != "COMMENT") {
       pd$lag_newlines[first_arg] <- 0L
     }
@@ -315,8 +339,12 @@ set_line_break_after_opening_if_call_is_multi_line <- function(pd,
 #' @inheritParams set_line_break_if_call_is_multi_line
 #' @keywords internal
 find_line_break_position_in_multiline_call <- function(pd) {
-  candidate <- (which(pd$token == "EQ_SUB") - 1L)[1]
-  ifelse(is.na(candidate), 3L, candidate)
+  candidate <- (which(pd$token == "EQ_SUB") - 1L)[1L]
+  if (is.na(candidate)) {
+    3L
+  } else {
+    candidate
+  }
 }
 
 
@@ -328,13 +356,18 @@ set_line_break_before_closing_call <- function(pd, except_token_before) {
     return(pd)
   }
   npd <- nrow(pd)
-  is_multi_line <- any(pd$lag_newlines[seq2(3L, npd - 1L)] > 0)
-  if (is_multi_line == 0) {
+  is_multi_line <- any(pd$lag_newlines[seq2(3L, npd - 1L)] > 0L)
+  if (is_multi_line == 0L) {
     exception <- which(pd$token_before %in% except_token_before)
     pd$lag_newlines[setdiff(npd, exception)] <- 0L
     return(pd)
   }
-  pd$lag_newlines[npd] <- 1L
+  idx_non_comment <- previous_non_comment(pd, npd)
+  if (pd$token[idx_non_comment] == "']'") {
+    pd$lag_newlines[idx_non_comment] <- 1L
+  } else {
+    pd$lag_newlines[npd] <- 1L
+  }
   pd
 }
 
@@ -345,10 +378,12 @@ remove_line_break_in_fun_call <- function(pd, strict) {
   if (is_function_call(pd)) {
     # no blank lines within function calls
     if (strict) {
-      pd$lag_newlines[lag(pd$token == "','") & pd$lag_newlines > 1 & pd$token != "COMMENT"] <- 1L
+      pd$lag_newlines[
+        lag(pd$token == "','") & pd$lag_newlines > 1L & pd$token != "COMMENT"
+      ] <- 1L
     }
-    if (nrow(pd) == 3) {
-      pd$lag_newlines[3] <- 0L
+    if (nrow(pd) == 3L) {
+      pd$lag_newlines[3L] <- 0L
     }
   }
   pd
@@ -357,15 +392,15 @@ remove_line_break_in_fun_call <- function(pd, strict) {
 
 set_linebreak_after_ggplot2_plus <- function(pd) {
   # if expression is unary, first token is +. Exclude this case.
-  is_plus_raw <- c(FALSE, pd$token[-1] == "'+'")
+  is_plus_raw <- c(FALSE, pd$token[-1L] == "'+'")
   if (any(is_plus_raw)) {
-    first_plus <- which(is_plus_raw)[1]
+    first_plus <- which(is_plus_raw)[1L]
     next_non_comment <- next_non_comment(pd, first_plus)
     is_plus_or_comment_after_plus_before_fun_call <-
-      lag(is_plus_raw, next_non_comment - first_plus - 1, default = FALSE) &
+      lag(is_plus_raw, next_non_comment - first_plus - 1L, default = FALSE) &
         (pd$token_after == "SYMBOL_FUNCTION_CALL" | pd$token_after == "SYMBOL_PACKAGE")
     if (any(is_plus_or_comment_after_plus_before_fun_call, na.rm = TRUE)) {
-      gg_call <- pd$child[[previous_non_comment(pd, first_plus)]]$child[[1]]
+      gg_call <- pd$child[[previous_non_comment(pd, first_plus)]]$child[[1L]]
       if (!is.null(gg_call) && isTRUE(gg_call$text[gg_call$token == "SYMBOL_FUNCTION_CALL"] == "ggplot")) {
         plus_without_comment_after <- setdiff(
           which(is_plus_raw),
